## ----------------
## Load data
## ----------------

library(rWSBIM1207)
data("peptides")

## ----------------
## Exploration
## ----------------

str(peptides)
length(peptides)
nchar(peptides)
table(nchar(peptides))
barplot(table(nchar(peptides)))

head(peptides)
tail(peptides)

## ----------------
## pattern matching
## ----------------

## grep et grepl

pattern <- "AAGE"
grep(pattern, peptides)
length(grep(pattern, peptides))

AAGE_peptides <- grep(pattern, peptides, 
                      value = TRUE)

grepl(pattern, peptides)

## substitution

head(peptides)

head(sub("AE", "XX", peptides))
head(sub("AE", "--", peptides))
head(sub("AE", "", peptides))

head(peptides)
head(sub("A", "X", peptides))
head(gsub("A", "X", peptides))


## ----------------
## Iteration
## ----------------

x <- 1:10

log(x[1])
log(x[2])
log(x[3])
## ...
log(x[10])

for (i in 1:length(x)) {
  print(log(x[i]))
}


res <- rep(NA, length(x))
res

for (i in 1:length(x)) {
  res[i] <- log(x[i])
}

res

## Apply log() to each element of x

sapply(x, log)
lapply(x, log)

## Vectorisation

log(x)

## ----------------------
## Writing new functions
## ----------------------

my_fun <- function(x, y) {
  message("First argument: ", x)
  message("Second argument: ", y)
  res <- x + y
  return(res)
}

z <- my_fun(12, 1)
z

## Analyse multiple files

library(rWSBIM1207)
library(tidyverse)

interroA.csv()
interroB.csv()

read_csv(interroA.csv())
read_csv(interroB.csv())

f <- c(interroA.csv(), interroB.csv())
f

interros <- lapply(f, read_csv)

class(interros)
length(interros)
interros

names(interros[[1]])
names(interros[[2]])

interroAB <- rbind(interros[[1]], 
                   interros[[2]])
interroAB

interroAB$serie <- c(rep("A", 100), 
                     rep("B", 105))

## mieux
interroAB$serie <- 
  c(rep("A", nrow(interros[[1]])),
    rep("B", nrow(interros[[2]])))

View(interroAB)

interroAB %>% 
  group_by(serie) %>% 
  summarise(m1 = mean(interro1, na.rm = TRUE),
            m2 = mean(interro2, na.rm = TRUE))

mean(read_csv(interroA.csv())$interro1, na.rm = TRUE)
mean(read_csv(interroB.csv())$interro1, na.rm = TRUE)


rbind(read_csv(interroA.csv()), 
      read_csv(interroB.csv()))
