library(dplyr)
library(tidyverse)

survey <- read.csv("data/survey_noNA.csv")
View(survey)
class(survey)

survey <- read_csv("data/survey_noNA.csv")
class(survey)
View(survey)
survey


# Selecting columns and filtering rows
s1 <- select(survey, record_id, sex, plot_id )
s1
s2 <- select(survey, -hindfoot_length, sex)
s2

f1 <- filter(survey, sex == "M")
f1

f2 <- filter(s2, sex == "M")
f2
s3 <- select(f1, genus, weight, species, sex)
s3



# Pipes 
s10 <- survey %>% filter(sex=="M") %>% select(genus, weight, species, sex)
s10

s3 == s10

# exercice 
# Using pipes, subset the surveys data to include animals collected before 1995
# and retain only the columns year, sex, and weight.
exo1 <- survey %>% filter(year < "1995") %>% select(year, sex, weight)
exo1
is.na(exo1)



# Mutate 
m1 <- survey %>% filter(sex=="F") %>% select(sex, weight, species) %>% mutate (weight2 = weight/2, weight3= weight*2)
m1

# exercice 
# Create a new data frame from the surveys data that meets the following criteria: 
# contains only the species_id column and a new column called hindfoot_half containing 
# values that are half the hindfoot_length values. In this hindfoot_half column, 
# there are no NAs and all values are less than 30.

df2 <- survey %>%
  filter(!is.na(hindfoot_length)) %>%
  mutate(hindfoot_half = hindfoot_length / 2) %>%
  filter(hindfoot_half < 30) %>%
  select(species_id, hindfoot_half)
df2



# Split-apply-combine data analysis 
survey %>% group_by(genus)



# The summarise() function 
survey %>% group_by(sex) %>% summarise(moy_sex = mean(weight, ra.rm=TRUE))

ss1 <- survey %>% group_by(sex, species_id) %>% summarise(moy=mean(weight, na.rm=TRUE))
ss1
head(ss1)
tail(ss1)
View(ss1)

ss3 <- survey %>% group_by(sex, species_id) %>% summarise(moy_hf= mean(hindfoot_length, na.rm=TRUE), max_hf = max(hindfoot_length, na.rm = TRUE), min_hf = min(hindfoot_length, na.rm = TRUE))
ss3

ss4 <- survey %>% group_by(sex, species_id) %>% summarise(moy=mean(weight, na.rm=TRUE)) %>% print(n=55)

ss5 <- survey %>% group_by(sex, species_id) %>% summarise(moy=mean(weight, na.rm=TRUE)) %>% arrange(desc(moy)) %>% print(n=50)
ss5


# Counting

c1 <- survey %>% count(species_id)
c1

c2 <- survey %>% group_by(species_id) %>% summarise(count = n())
c2

c1 == c2

c3 <- survey %>% count(species, sort= TRUE)
c3

c4 <- survey %>% count(species_id, sex, sort=TRUE)
c4

c5 <- survey %>% count(species_id, sex) %>% arrange(species_id, desc(sex))
c5


# exercice 
# How many animals were caught in each plot_type surveyed?
nb <- survey %>% count(plot_type, sort= TRUE)
nb

# Use group_by() and summarize() to find the mean, min,and max hindfoot length 
# for each species (using species_id).Also add the number of observations (hint: see ?n)
exo <- survey %>% group_by(species_id) %>% summarise(moy_hf= mean(hindfoot_length, na.rm=TRUE), 
                                                          max_hf = max(hindfoot_length, na.rm = TRUE), 
                                                          min_hf = min(hindfoot_length, na.rm = TRUE), 
                                                          nb_obs=n()) 
exo

#What was the heaviest animal measured in each year? 
# Return the columns year, genus, species_id, and weight
ex <- survey %>% filter(!is.na(weight)) %>%
  group_by(year) %>%
  filter(weight == max(weight)) %>%
  select(year, genus, species, weight) %>%
  arrange(year)
ex



# Reshaping data
# pivoting the data into a wider format
survey_gw <- survey %>% 
  filter(!is.na(weight)) %>% 
  group_by(genus, plot_id) %>% 
  summarize(mean_weight = mean(weight))
survey_gw
# plot_id = les identifiants de parcelles sur lesql ces individus ont été collectés 

wider <- survey_gw %>% pivot_wider(names_from= genus, 
            values_from = mean_weight)
wider

# survey_gw => 240 valeurs réparties sur 24 lignes correspondant aux 
# 24 plot_id, et on a 10 colonnes correspondant aux 10 genres qui nous intéressent. 
# on a une différence en nb de valeurs entre survey_gw et wider pcq dans le 1er, 
# on a des genres qui se répètent un gd nb de fois et les plot_id aussi. 
# par contre, les valeurs de poids moyens sont les mêmes mais ont été transformées 
# ds un format différent



# pivoting the data into a longer format
longer <- wider %>% pivot_longer(names_to = "genus", 
                       values_to = "mean_weight", 
                       -plot_id)
longer
# d'un format large, on recréé un format long correspondant à nos jeux de données initiaux. 


# exercices 
# Spread the surveys data frame with year as columns, plot_id as rows,
# and the number of genera per plot as the values. You will need to summarize before reshaping,
# and use the function n_distinct() to get the number of unique genera within 
# a particular chunk of data. It’s a powerful function! See ?n_distinct for more.
new_survey <- survey %>% filter(plot_id) %>% select(year)



# 


# The surveys data set has two measurement columns: hindfoot_length and weight. 
# This makes it difficult to do things like look at the relationship between mean values
# of each measurement per year in different plot types. Let’s walk through a common solution 
# for this type of problem. First, use pivot_longer() to create a dataset where we have a key 
# column called measurement and a value column that takes on the value of either hindfoot_length 
# or weight.



































