library(dplyr)
library(tidyverse)
library(rWSBIM1207)
data(jdf)


# 1 Combining tables

# joindre deux jeux de données via une variable commune (ici, uniprot)
full_join(jdf1, jdf2)


# La f° names() permet de visualiser le nom des variables et potentionnellement en match 1
# avec la mm variable d'un autre jeu de données. Il est possible que les deux noms ne soient
# pas écrits de la même façon => on utilise le code ci-dessous
names(jdf3)
full_join(jdf1, jdf3)
full_join(jdf1, jdf3, by = c("uniprot" = "UniProt"))


# exercice 
# Using the full_join function demonstrated above, join tables jdf4 and jdf5.
# What has happened for observations P26039 and P02468? 
# => answer : ils sont présents dans un tibble, mais pas dans l'autre => Missing data
full_join(jdf4, jdf5)




# 2 Different types of joins

# An inner join keeps observations that are present in both tables.
inner_join(jdf1, jdf2)

# A left join keeps observations that are present in the left (first) table, 
# dropping those that are only present in the other.
left_join(jdf1, jdf2)

# A right join keeps observations that are present in the right (second) table, 
# dropping those that are only present in the other.
right_join(jdf1, jdf2)

# A full join keeps all observations.
full_join(jdf1, jdf2)


# exercices 

# Join tables jdf4 and jdf5, keeping only observations in jdf4.
left_join(jdf4, jdf5)

# Join tables jdf4 and jdf5, keeping only observations in jdf5.
right_join(jdf4, jdf5)

# Join tables jdf4 and jdf5, keeping observations observed in both tables.
inner_join(jdf4, jdf5)




# 3 Multiple matches (ask question about this)

# a variable (= key) could be repeated twice. So matching two tibbles together
# could help to complete with correct informations about that doubled variable.
# example of correct info : the gene's name 
hiii <- inner_join(jdf6, jdf2)

# this could be very useful, but it could also lead us to wrong informations when matching 
# two tibbles with, both, the same variable doubled twice. 
hiiii <- inner_join(jdf6, jdf7)




# 4 Matching across multiple keys

# this consists of joining two tables via the match of multiple keys.
# Those keys are sometimes encoded with different names => do not get confused

names(jdf6)
names(jdf7)

inner_join(jdf6, jdf7, by = c("uniprot" = "uniprot", "isoform" = "isoform_num"))


# exercice (ask question about this too)
# Can you think of another way to merge (= combiner) tables jdf6 and jdf7 using the two keys?
i <- grep("isoform", names(jdf7))
names(jdf7)[i] <- "isoform"
inner_join(jdf6, jdf7)




# 5 Merge in base R (equivalence between the dplyr and base packages functions)

library(base)

# inner joining (inner_join(jdf1, jdf2))
i <- merge(jdf1, jdf2)

# left joining (left_join(jdf1, jdf2))
l <- merge(jdf1, jdf2, all.jdf1 = TRUE)

# right joining (right_join(jdf1, jdf2))
r <- merge(jdf1, jdf2, all.jdf2 = TRUE)

# full joining (full_join(jdf1, jdf2))
f <- merge(jdf1, jdf2, all.jdf1 = TRUE, all.jdf2 = TRUE)




# 6 Row and column binding 

# binding dataframes by columns

d1 <- data.frame( x= c(1, 2, 3), y= c(1, 2, 3))
d1

d2 <- data.frame (a = c(4, 5), b = c(4,5))
d2

# if we try to bind d1 and d2, there is an error msg because the colums 
# have different names
try(rbind(d1, d2))


# We need to get them to have the same names so : 
names(d2) <- names(d1)


# now we're good and can bind the two dataframes (only if the number of colums and rows 
# matches exactly)
rbind(d1, d2)


# if we want to join two dataframes, their number of colums and rows must exactly match
d3 <- data.frame(v1 = c(1, 2), v2 = c(3, 4), v3 = c(5,6))
d3

cbind(d2, d3)


# The dataframes's variables we bind don't have to be from one same class (it'll 
# be converted if necessary)
d4 <- data.frame(x = letters[1:2], y = letters[1:2])
d4

b <- rbind(d1, d4)

str(b)


# Attention, 
# cbind = binding colums
# rbind = binding rows






